<?php
/**
 * Lightning Header Top Description
 *
 * @package Lightning Header Top Description
 */

class Lightning_Header_Top_Description {
	/**
	 * Constructor.
	 */
	public function __construct() {
		add_filter( 'header_top_description', array( __CLASS__, 'change_header_top_description' ) );
		add_action( 'save_post', array( __CLASS__, 'custom_field_save' ) );
		add_action( 'admin_menu', array( __CLASS__, 'custom_field_set' ) );
	}

	/**
	 * カスタムフィールドの入力エリア
	 */
	public static function custom_field_form() {
		global $post;

		$post_meta = get_post_meta( $post->ID, 'header_top_description', true );
		$field     = '<label><input type="text" name="header_top_description" value="' . $post_meta . '" style="width:100%;margin-top:5px;"></label>';
		$field    .= '<p>' . __( 'If there is any entry here, the entry will be reflected in the catch phrase at the top of the page.', 'lightning-pro' ) . '</p>';

		echo $field;
	}

	/**
	 * カスタムフィールドを保存
	 *
	 * @param int $post_id 投稿ID
	 */
	public static function custom_field_save( $post_id ) {
		$post_meta = get_post_meta( $post_id, 'header_top_description', true );
		// 値がある場合.
		if ( ! empty( $_POST['header_top_description'] ) ) {
			// 値が登録されている場合.
			if ( ! empty( $post_meta ) ) {
				update_post_meta( $post_id, 'header_top_description', $_POST['header_top_description'] );
				// 新規登録時
			} else {
				add_post_meta( $post_id, 'header_top_description', $_POST['header_top_description'] );
			}
		} else { // チェックされていない場合.
			delete_post_meta( $post_id, 'header_top_description' );
		}
	}


	/**
	 * カスタムフィールドを設置
	 */
	public static function custom_field_set() {
		$field_title = __( 'Article Description for Header Top', 'lightning-pro' );
		$post_types  = get_post_types(
			array(
				'public' => true,
			)
		);
		foreach ( $post_types as $post_type ) {
			add_meta_box( 'header_top_description', $field_title, array( __CLASS__, 'custom_field_form' ), $post_type, 'normal', 'high' );
		}
	}

	/**
	 * Header Top Description を書き換え
	 */
	public static function change_header_top_description( $description ) {
		if ( is_singular() ) {
			global $post;
			$post_meta = get_post_meta( $post->ID, 'header_top_description', true );
			if ( ! empty( $post_meta ) ) {
				$description = $post_meta;
			}
		}
		return $description;
	}
}

new Lightning_Header_Top_Description();
